clear all;

% tunable parameters
MPLOT = 5;   % scale of model parameter plot
CPLOT = 1;   % scale of covariance plot

% standard time axis
N=256;  % must be even, best if a power of 2
Dt=1.0;
tmax=Dt*(N-1); 
t=Dt*[0:N-1]'; 
tmid=tmax/2.0;

% exact gamma*cos(w0T)exp(-sT) covariance function
n=6;  % number of oscillations on (0,tmax) interal
w0 = n*2*pi/tmax;  % angular frequency of oscilation
s = 20.0/tmax;  % decay rate
gamma = 1.0; % variance
gamma2 = gamma^2;
c = gamma2*cos(w0*(t-tmid)).*exp(-s*abs(t-tmid));

% realize a time series with a specified covariance
ctilde = fft(c);  % Fourier transform of c
casd = abs(ctilde);   % amplitude spectral density
d = random('Normal',0.0,1.0,N,1); % make random numbers
d = d - mean(d);     % remove mean
dtilde = fft(d);     % Fourier transform of d
dasd = abs(dtilde);       % a.s.d. of d
dtilde = (casd./dasd).*dtilde;  % adjust so has a.s.d. of c
d = real(ifft(dtilde)); % inverse Fourier transform
vard = var(d);     % variance of d
d = (gamma/sqrt(vard))*d; % normalize mf to variance gamma^2

cest = xcorr(d,d)/N; % estimated covariance

% plot this covariance
figure(1);
clf;
hold on;
set(gca,'LineWidth',2);
set(gca,'FontSize', 14);
axis( [ -tmid, tmid, -CPLOT, CPLOT] );
xlabel('time lag t (s)');
ylabel('c(t)');
plot(t-tmid,c,'k-','LineWidth',3);
tc = Dt*[(-N+1):(N-1)]';
plot(tc,cest,'k:','LineWidth',3);

% time series figure
figure(2);
clf;
set(gca,'LineWidth',2);
set(gca,'FontSize', 14);
axis( [ 0, tmax, -MPLOT, MPLOT] );
xlabel('time t (s)');
ylabel('d(t)');
hold on;
plot(t,d,'k-','LineWidth',3);


